@@ -1,29 +1,23 @@
-#!/usr/bin/env python
-# -*- coding: utf-8 -*-
-# author: bcabezas@apsl.net
+# coding: utf-8
 
 from cms.plugin_base import CMSPluginBase
 from cms.plugin_pool import plugin_pool
 from .models import SliderPlugin
+from django.utils.translation import ugettext_lazy as _
 
 
 class CMSSliderPlugin(CMSPluginBase):
     model = SliderPlugin
-    name = 'Slider Plugin'
+    name = _('Slider')
     render_template = 'nivo/slider.html'
     text_enabled = False
     admin_preview = False
 
     def render(self, context, instance, placeholder):
-        if instance.height and instance.width:
-            size = (instance.width, instance.height)
-        else:
-            size = None
         context.update({
             'object': instance,
             'placeholder': placeholder,
-            'images': instance.album.images.iterator(),
-            'size': size,
+            'images': instance.images,
         })
         return context
 
